netapp_ontap.models.cluster_peer_setup_response_authentication API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cluster_peer_setup_response_authentication`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ClusterPeerSetupResponseAuthenticationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterPeerSetupResponseAuthentication object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `expiry_time GET POST PATCH`

    The date and time the passphrase will expire. The default expiry time is one hour.

    Example: 2017-01-25T11:20:13.000+0000

  `passphrase GET POST PATCH`

    A password to authenticate the cluster peer relationship.